@@ -10,7 +10,7 @@ import os
 import logging
 import re
 import pandas as pd
-from email_notification import email_notification
+from .email_notification import email_notification
 from .utils import (
     execute_run_databricks,
     execute_run_postgres,
@@ -862,12 +862,14 @@ class RuleManager:
                         self.logger.warning(f"Rule {rule_name} (ID: {rule_id}) failed. Sending failure email and stopping.")
 
                         if email_enabled:
+                            summary_df = self.spark.createDataFrame(results)
                             email_notification(
                                 current_time_et=current_time_et,
                                 recipient_name=recipient_email,
                                 subject=f"Rule {rule_name} Failed",
                                 env=env,
                                 body_part=rule.get('COMMENTS', 'Rule failed'),
+                                df=summary_df,
                                 footer=f"Rule ID: {rule_id}",
                                 is_failure=True,
                                 file_name=rule.get("FILE_NAME"),
@@ -892,6 +894,17 @@ class RuleManager:
 
                     self.rules["RULES"][idx] = rule
 
+                    results.append({
+                        "RULE_ID": rule.get('RULE_ID'),
+                        "RULE_NAME": rule.get('RULE_NAME'),
+                        "DOMAIN_NAME": rule.get('DOMAIN_NAME'),
+                        "TABLES_CHECKED": rule.get('TABLE_NAME'),
+                        "TEAM_NAME": rule.get('TEAM_NAME'),
+                        "STATUS": rule.get('STATUS'),
+                        "COMMENTS": rule.get('COMMENTS'),
+                        "TIME": rule.get('TIME', datetime.now(timezone('UTC')).isoformat())
+                    })
+
                     if rule.get("DROP_TEMP_TABLES", False):
                         self.logger.info(f"Dropping temp tables for rule: {rule['RULE_NAME']}")
                         self.drop_temp_tables(rule)
@@ -910,10 +923,11 @@ class RuleManager:
                             )
 
                     self.logger.info(f"Rule {idx + 1} processed successfully")
-                    results.append(rule)
+                    
 
             # 📤 Send final summary email
             if email_enabled:
+                summary_df = self.spark.createDataFrame(results)
                 email_notification(
                     current_time_et=current_time_et,
                     recipient_name=recipient_email,
@@ -921,7 +935,8 @@ class RuleManager:
                     env=env,
                     body_part=f"{len(results)} rules processed successfully",
                     footer=f"BATCH_ID: {BATCH_ID}",
-                    url=email_api_url
+                    url=email_api_url,
+                    df=summary_df
                 )
 
             print(json.dumps({ "BATCH_ID": BATCH_ID, "RULES": results }, indent=2))
