@@ -1,6 +1,7 @@
 <TAGS>
 INSERT INTO <DATABASE_NAME>.pybrv_meta.pybrv_business_rule_check_result (
-    unique_rule_identifier    
+    batch_id
+    ,unique_rule_identifier    
     ,execution_id              
     ,team_name                 
     ,rule_name                 
@@ -23,6 +24,7 @@ INSERT INTO <DATABASE_NAME>.pybrv_meta.pybrv_business_rule_check_result (
     ,last_modified_ts 
 )
 SELECT
+    <BATCH_ID>,
     <UNIQUE_RULE_IDENTIFIER>,
     <EXECUTION_ID>,
     '<TEAM_NAME>',
